==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Effect/crossfade/translations/crossfade_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>EffectCrossfadeFactory</name>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="30"/>
        <source>Crossfade Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="51"/>
        <source>About Crossfade Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="52"/>
        <source>Qmmp Crossfade Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Crossfade Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Overlap:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>ms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Effect/crossfade/translations/crossfade_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>EffectCrossfadeFactory</name>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="31"/>
        <source>Crossfade Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="52"/>
        <source>About Crossfade Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="53"/>
        <source>Qmmp Crossfade Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectcrossfadefactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Crossfade Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Overlap:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>ms</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
